@@ -1,9 +1,4 @@
-"""Create a tmux workspace from a workspace :py:obj:`dict`.
-
-tmuxp.workspace.builder
-~~~~~~~~~~~~~~~~~~~~~~~
-
-"""
+"""Create a tmux workspace from a workspace :py:obj:`dict`."""
 import logging
 import time
 import typing as t
@@ -33,7 +28,6 @@ class WorkspaceBuilder:
 
     Examples
     --------
-
     >>> import yaml
 
     >>> session_config = yaml.load('''
@@ -98,7 +92,7 @@ class WorkspaceBuilder:
 
     1. Load JSON / YAML file via via :class:`pathlib.Path`::
 
-           from tmuxp import config_reader
+           from tmuxp._internal import config_reader
            session_config = config_reader.ConfigReader._load(raw_yaml)
 
        The reader automatically detects the file type from :attr:`pathlib.suffix`.
@@ -106,7 +100,7 @@ class WorkspaceBuilder:
        We can also parse raw file::
 
            import pathlib
-           from tmuxp import config_reader
+           from tmuxp._internal import config_reader
 
            session_config = config_reader.ConfigReader._from_file(
                pathlib.Path('path/to/config.yaml')
@@ -161,7 +155,6 @@ class WorkspaceBuilder:
         TODO: Initialize :class:`libtmux.Session` from here, in
         ``self.session``.
         """
-
         if plugins is None:
             plugins = []
         if not session_config:
@@ -189,11 +182,13 @@ class WorkspaceBuilder:
 
     @property
     def session(self) -> Session:
+        """Return tmux session using in workspace builder session."""
         if self._session is None:
             raise exc.SessionMissingWorkspaceException()
         return self._session
 
     def session_exists(self, session_name: str) -> bool:
+        """Return true if tmux session already exists."""
         assert session_name is not None
         assert isinstance(session_name, str)
         assert self.server is not None
@@ -222,7 +217,6 @@ class WorkspaceBuilder:
         append : bool
             append windows in current active session
         """
-
         if not session:
             if not self.server:
                 raise exc.TmuxpException(
@@ -559,6 +553,7 @@ class WorkspaceBuilder:
                 window.set_window_option(key, val)
 
     def find_current_attached_session(self) -> Session:
+        """Return current attached session."""
         assert self.server is not None
 
         current_active_pane = get_current_pane(self.server)
@@ -575,4 +570,5 @@ class WorkspaceBuilder:
         )
 
     def first_window_pass(self, i: int, session: Session, append: bool) -> bool:
+        """Return True first window, used when iterating session windows."""
         return len(session.windows) == 1 and i == 1 and not append
